LabeledInstr

Enum LabeledInstr 

pub enum LabeledInstr<B> {
    Labeled(usize, Instr<Name, B>),
    Unlabeled(Instr<Name, B>),
}
By default each jump or goto just contains a usize offset into the instruction vector. This representation is efficient but hard to work with, so we support mapping this representation into one where any instruction can have an explicit label, and jumps point to those explicit labels, and then going back to the offset based representation for execution.

Variants



Labeled(usize, Instr<Name, B>)



Unlabeled(Instr<Name, B>)