pub fn prune_labels<B: BV>(instrs: Vec<LabeledInstr<B>>) -> Vec<LabeledInstr<B>>Expand description
Remove labels which are not the targets of any jump or goto.
pub fn prune_labels<B: BV>(instrs: Vec<LabeledInstr<B>>) -> Vec<LabeledInstr<B>>Remove labels which are not the targets of any jump or goto.