BlockInstr

Enum BlockInstr 

pub enum BlockInstr<B> {
    Decl(SSAName, Ty<SSAName>),
    Init(SSAName, Ty<SSAName>, Exp<SSAName>),
    Copy(BlockLoc, Exp<SSAName>),
    Monomorphize(SSAName),
    Call(BlockLoc, bool, Name, Vec<Exp<SSAName>>),
    PrimopUnary(BlockLoc, Unary<B>, Exp<SSAName>),
    PrimopBinary(BlockLoc, Binary<B>, Exp<SSAName>, Exp<SSAName>),
    PrimopVariadic(BlockLoc, Variadic<B>, Vec<Exp<SSAName>>),
}
BlockInstr is the same as Instr but restricted to just instructions that can appear in basic blocks, and with all names replaced by SSAName.

Variants



Decl(SSAName, Ty<SSAName>)



Init(SSAName, Ty<SSAName>, Exp<SSAName>)



Copy(BlockLoc, Exp<SSAName>)



Monomorphize(SSAName)



Call(BlockLoc, bool, Name, Vec<Exp<SSAName>>)



PrimopUnary(BlockLoc, Unary<B>, Exp<SSAName>)



PrimopBinary(BlockLoc, Binary<B>, Exp<SSAName>, Exp<SSAName>)



PrimopVariadic(BlockLoc, Variadic<B>, Vec<Exp<SSAName>>)

Implementations

Source

impl<B: BV> BlockInstr<B>

pub fn write_ssa(&self) -> Option<(SSAName, Option<SSAName>)>

pub fn write(&self) -> Option<Name>

pub fn declares(&self) -> Option<Name>