pub enum Edge {
Jump(bool),
Goto,
Continue,
}Expand description
An edge between basic blocks in the control flow graph. The edge corresponds to the Terminator of the node the edge comes from.
Variants