CFG

Struct CFG 

pub struct CFG<B> {
    pub root: NodeIndex,
    pub graph: Graph<Block<B>, Edge, Directed>,
}

Fields

root: NodeIndexgraph: Graph<Block<B>, Edge, Directed>

Implementations

Source

impl<B: BV> CFG<B>

pub fn new(instrs: &[LabeledInstr<B>]) -> Self

Construct a control flow graph from a slice of labeled instructions. Note that the set of labels should be pruned with super::prune_labels, otherwise the control flow graph will end up containing redundant blocks.

pub fn all_vars_typed(&self, ret_ty: &Ty<Name>) -> HashMap<Name, Ty<Name>>

Returns a HashMap of all variables declared in a CFG. Also includes the special RETURN variable which is used to signal the return value of a function, hence why the return type of the function is also passed as an argument.

pub fn ssa(&mut self)

Put the CFG into single static assignment (SSA) form.

pub fn dot(&self, output: &mut dyn Write, symtab: &Symtab<'_>) -> Result<()>

Generate a dot file of the CFG. For debugging.