pub fn self_test<'ir, B: BV>(
num_threads: usize,
arch: Vec<Def<Name, B>>,
symtab: Symtab<'ir>,
isa_config: &ISAConfig<B>,
args: &[Name],
arg_tys: &[Ty<Name>],
ret_ty: &Ty<Name>,
instrs1: Vec<Instr<Name, B>>,
instrs2: Vec<Instr<Name, B>>,
) -> boolExpand description
Test that a rewritten function body is equivalent to the original body by constructing a symbolic execution problem that proves this. Note that this function should called with an uninitialized architecture.